==> react-annotate-1.8.16.tgz: package/Sidebar/index.js <==
import React from "react";
import { styled, makeStyles } from "@material-ui/core/styles";
import TaskDescription from "../TaskDescriptionSidebarBox";
import ImageSelector from "../ImageSelectorSidebarBox";
import RegionSelector from "../RegionSelectorSidebarBox";
import History from "../HistorySidebarBox";
import DebugBox from "../DebugSidebarBox";
import TagsSidebarBox from "../TagsSidebarBox";
import KeyframesSelector from "../KeyframesSelectorSidebarBox";
var Container = styled("div")({});
var emptyArr = [];
export var Sidebar = function Sidebar(_ref) {
  var debug = _ref.debug,
      taskDescription = _ref.taskDescription,
      keyframes = _ref.keyframes,
      images = _ref.images,
      regions = _ref.regions,
      history = _ref.history,
      labelImages = _ref.labelImages,
      currentImage = _ref.currentImage,
      currentVideoTime = _ref.currentVideoTime,
      imageClsList = _ref.imageClsList,
      imageTagList = _ref.imageTagList,
      onChangeImage = _ref.onChangeImage,
      onSelectRegion = _ref.onSelectRegion,
      onSelectImage = _ref.onSelectImage,
      onChangeRegion = _ref.onChangeRegion,
      onDeleteRegion = _ref.onDeleteRegion,
      _onRestoreHistory = _ref.onRestoreHistory,
      onChangeVideoTime = _ref.onChangeVideoTime,
      onDeleteKeyframe = _ref.onDeleteKeyframe,
      onShortcutActionDispatched = _ref.onShortcutActionDispatched;
  if (!regions) regions = emptyArr;
  return React.createElement(Container, null, debug && React.createElement(DebugBox, {
    state: debug,
    lastAction: debug.lastAction
  }), taskDescription && (taskDescription || "").length > 1 && React.createElement(TaskDescription, {
    description: taskDescription
  }), labelImages && React.createElement(TagsSidebarBox, {
    currentImage: currentImage,
    imageClsList: imageClsList,
    imageTagList: imageTagList,
    onChangeImage: onChangeImage,
    expandedByDefault: true
  }), React.createElement(RegionSelector, {
    regions: regions,
    onSelectRegion: onSelectRegion,
    onChangeRegion: onChangeRegion,
    onDeleteRegion: onDeleteRegion
  }), keyframes && React.createElement(React.Fragment, null, console.log("KEYFRAMES = ", keyframes), React.createElement(KeyframesSelector, {
    currentVideoTime: currentVideoTime,
    keyframes: keyframes,
    onChangeVideoTime: onChangeVideoTime,
    onDeleteKeyframe: onDeleteKeyframe
  })), React.createElement(History, {
    history: history,
    onRestoreHistory: function onRestoreHistory() {
      return _onRestoreHistory();
    }
  }));
};
export default Sidebar;

==> react-annotate-1.8.21.tgz: package/Sidebar/index.js <==
import { makeStyles, styled } from "@material-ui/core/styles";
import React from "react";
import DebugBox from "../DebugSidebarBox";
import History from "../HistorySidebarBox";
import ImageSelector from "../ImageSelectorSidebarBox";
import KeyframesSelector from "../KeyframesSelectorSidebarBox";
import RegionSelector from "../RegionSelectorSidebarBox";
import TagsSidebarBox from "../TagsSidebarBox";
import TaskDescription from "../TaskDescriptionSidebarBox";
var Container = styled("div")({});
var emptyArr = [];
export var Sidebar = function Sidebar(_ref) {
  var debug = _ref.debug,
      taskDescription = _ref.taskDescription,
      keyframes = _ref.keyframes,
      images = _ref.images,
      regions = _ref.regions,
      history = _ref.history,
      labelImages = _ref.labelImages,
      currentImage = _ref.currentImage,
      currentVideoTime = _ref.currentVideoTime,
      imageClsList = _ref.imageClsList,
      imageTagList = _ref.imageTagList,
      onChangeImage = _ref.onChangeImage,
      onSelectRegion = _ref.onSelectRegion,
      onSelectImage = _ref.onSelectImage,
      onChangeRegion = _ref.onChangeRegion,
      onDeleteRegion = _ref.onDeleteRegion,
      _onRestoreHistory = _ref.onRestoreHistory,
      onChangeVideoTime = _ref.onChangeVideoTime,
      onDeleteKeyframe = _ref.onDeleteKeyframe,
      onShortcutActionDispatched = _ref.onShortcutActionDispatched;
  if (!regions) regions = emptyArr;
  return React.createElement(Container, null, debug && React.createElement(DebugBox, {
    state: debug,
    lastAction: debug.lastAction
  }), taskDescription && (taskDescription || "").length > 1 && React.createElement(TaskDescription, {
    description: taskDescription
  }), labelImages && React.createElement(TagsSidebarBox, {
    currentImage: currentImage,
    imageClsList: imageClsList,
    imageTagList: imageTagList,
    onChangeImage: onChangeImage,
    expandedByDefault: true
  }), React.createElement(RegionSelector, {
    regions: regions,
    onSelectRegion: onSelectRegion,
    onChangeRegion: onChangeRegion,
    onDeleteRegion: onDeleteRegion
  }), keyframes && React.createElement(React.Fragment, null, React.createElement(KeyframesSelector, {
    currentVideoTime: currentVideoTime,
    keyframes: keyframes,
    onChangeVideoTime: onChangeVideoTime,
    onDeleteKeyframe: onDeleteKeyframe
  })), React.createElement(History, {
    history: history,
    onRestoreHistory: function onRestoreHistory() {
      return _onRestoreHistory();
    }
  }));
};
export default Sidebar;
